#region Using Statements
using System;
using System.Collections.Generic;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Storage;
#endregion

namespace TiledLevel
{
    /// <summary>
    /// A simple example game showing a character jumping around a tiled map.
    /// </summary>
    public class Game : Microsoft.Xna.Framework.Game
    {
        ContentManager content;
        SpriteBatch batch;

        Player player;
        Map map;

        public Game()
        {
            Global.graphics = new GraphicsDeviceManager(this);
            content = new ContentManager(Services);
            this.Window.AllowUserResizing = true;
        }


        void Window_ClientSizeChanged(object sender, EventArgs e)
        {
            // Update our stored copy of the screen size.
            Global.screenWidth = Global.graphics.GraphicsDevice.Viewport.Width;
            Global.screenHeight = Global.graphics.GraphicsDevice.Viewport.Height;
        }

        /// <summary>
        /// Allows the game to perform any initialization it needs to before starting to run.
        /// This is where it can query for any required services and load any non-graphic
        /// related content.  Calling base.Initialize will enumerate through any components
        /// and initialize them as well.
        /// </summary>
        protected override void Initialize()
        {
            Window_ClientSizeChanged(null, null);

            // Create the map and player.
            map = new Map();
            player = new Player();

            // Create a sprite batch we will use to render the player.
            batch = new SpriteBatch(Global.graphics.GraphicsDevice);

            // Subscribe to the game window's ClientSizeChanged event.
            Window.ClientSizeChanged += new EventHandler(Window_ClientSizeChanged);

            base.Initialize();
        }

        protected override void LoadContent()
        {
            Map.LoadGraphicsContent(content);
            Player.LoadGraphicsContent(content);

            base.LoadContent();
        }

        /// <summary>
        /// Allows the game to run logic such as updating the world,
        /// checking for collisions, gathering input and playing audio.
        /// </summary>
        /// <param name="gameTime">Provides a snapshot of timing values.</param>
        protected override void Update(GameTime gameTime)
        {
            // Allows the game to exit
            if (GamePad.GetState(PlayerIndex.One).Buttons.Back == ButtonState.Pressed)
                this.Exit();

            // Update the player.
            player.Update(map);

            base.Update(gameTime);
        }


        /// <summary>
        /// This is called when the game should draw itself.
        /// </summary>
        /// <param name="gameTime">Provides a snapshot of timing values.</param>
        protected override void Draw(GameTime gameTime)
        {
            Global.graphics.GraphicsDevice.Clear(Color.CornflowerBlue);

            // Render the map.
            map.Draw();

            // Render the player.
            batch.Begin();
            player.Draw(batch, map);
            batch.End();

            base.Draw(gameTime);
        }
    }
}
